==> haskell-hls-alternate-number-format-plugin-2.1.0.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-Cz41c63Corn7tSuq4zGAow

key:
    hls-alternate-number-format-plugin-2.1.0.0-Cz41c63Corn7tSuq4zGAow

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ba290c8d97bd1dd066469c31ebece62b
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-Cz41c63Corn7tSuq4zGAow

depends:
    aeson-2.1.2.1-AuEsVg6Hhe2CPhaLp40FYe base-4.17.2.1 containers-0.6.7
    extra-1.7.16-2NFI8foRfl5F586yJkh1o1 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-IfdVyiF6AwPDHn2TbAPnXk
    hie-compat-0.3.1.2-IkeVSMKPoXJ5qEiKo06jB7
    hls-graph-2.1.0.0-CKpYjZtV40aGyPfbCsIcyO
    hls-plugin-api-2.1.0.0-2tKKyoZfjr7D6pGZz9pYOL
    lens-5.3.1-DW98VpYgL8e3Qofq450fQJ
    lsp-2.1.0.0-6qUz56YkN9c2lHkJ0EY2b5 mtl-2.2.2
    regex-tdfa-1.3.2.4-2tggK3dv6qG2BQKi0Zlyyt
    syb-0.7.3-GzxvBIT7N6LHXGQxqlBVFk text-2.0.2
    unordered-containers-0.2.20-FOY8P5Y3sqjANbVUEJi9Vi

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-alternate-number-format-plugin-2.1.0.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-5gMBtH2imLhOmv5rJVFVL

key:
    hls-alternate-number-format-plugin-2.1.0.0-5gMBtH2imLhOmv5rJVFVL

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ed250803a330edba15820bb7e3fe4788
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-5gMBtH2imLhOmv5rJVFVL

depends:
    aeson-2.1.2.1-6ANjbGmrSDg8K6hz3VmYXP base-4.17.2.1 containers-0.6.7
    extra-1.7.16-I47Rfrva8J15uJNg6ub4mo ghc-boot-th-9.4.8
    ghcide-2.1.0.0-AxhzWaQkdjgHPWGvAIsyT3
    hie-compat-0.3.1.2-IkeVSMKPoXJ5qEiKo06jB7
    hls-graph-2.1.0.0-AANfnwsQjSf2H6XCySy8Im
    hls-plugin-api-2.1.0.0-ChwlSnK1lzVJ03qjCmFPJ2
    lens-5.3.1-7KUGOKnL0sFAtVCcawlRvA lsp-2.1.0.0-b02KkAmTxV7yZ6tPxe7VB
    mtl-2.2.2 regex-tdfa-1.3.2.4-FgXHJp0Jxc99bydELndP6q
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2
    unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
